classdef SolarSystem < handle
    
    properties
        ActivePlanets = {};
        
    end
    
    methods
        
        function InitializeSystem(system)
            S=Sun(system);
            addPlanet(system, S);
        end
        
        function addPlanet(system,planet)
            if isempty(system.ActivePlanets)
                system.ActivePlanets{1}=planet;
            end
            for i=1:length(system.ActivePlanets)
                if strcmpi(system.ActivePlanets{i}.Symbol, planet.Symbol);
                    return
                elseif i==length(system.ActivePlanets) && system.ActivePlanets{i} ~= planet
                    system.ActivePlanets{end+1} = planet;
                end
            end
        end
        
        function resetSystem(system)
            for i = length(system.ActivePlanets):1
                die(system.ActivePlanets{i});
            end
            system.ActivePlanets = {};
            InitializeSystem(system)
            
        end
        
        
        function size = getSize(system)
            size = 2E+008;
            for i = 1:length(system.ActivePlanets)
                temp = abs(system.ActivePlanets{i}.DistanceFromSun);
                if 2*temp > size
                    size = 2*temp;
                end
            end
        end
        
        function planets = getPlanets(system)
            for i=1:length(system.ActivePlanets)
                planets(i)=system.ActivePlanets{i};
            end
        end
        
        function [t, y] = solveODE(system,session,extra)
            Options=[];
            years=extra{1};
            
            ode_selected=extra{2}; % ode_selected is a cell :s, default=45
            ode_selected=ode_selected{1};
            
            if numel(extra)>=3
                ode_step=extra{3};
                Options.InitialStep = ode_step;
                if numel(extra) == 4
                    ode_error=extra{4};
                    Options.AbsTol = ode_error(1);
                    Options.RelTol = ode_error(2);
                end
            end
            
            system=session.System;
            objects ={};
            x=[];
            h=waitbar(0, 'Initializing...');
            for i=1:length(system.ActivePlanets)
                waitbar(i/length(system.ActivePlanets));
                planet=system.ActivePlanets{i};
                objects{end+1} = planet;
                x0(i,:)=[planet.InitialPosition planet.InitialVelocity];
                x=[x x0(i,:)];
                if ~isempty(planet.Moons)&&(planet.IncludeMoons==1)
                    for j=1:length(planet.Moons)
                        moons{j}=planet.Moons{j};
                        objects{end+1}=moons{j};
                        y0(j,:)=[moons{j}.InitialPosition moons{j}.InitialVelocity];
                        x=[x y0(j,:)];
                    end
                end
            end
            close(h)
            
            t_input=[0, years];
            if any(any(strcmp(ode_selected,{'s3odr4' 's5odr4a' 's7odr6' 's9odr6a' 's15odr8'}))) % or any other s-type ode
                switch ode_selected
                    case 's3odr4'
                        stage = 3;
                    case 's5odr4a'
                        stage = 5;
                    case 's7odr6'
                        stage = 7;
                    case 's9odr6a'
                        stage = 9;
                    case 's15odr8'
                        stage = 15;
                end
                tic
                [t,y]=anadromic(@(t,z,objs)findprime(t,z,objects),years,x,ode_step,objects,stage);
                toc
                
            else
                tic
                ode_selected = str2func(ode_selected);
                [t,y]=ode_selected(@(t,z,objs) findprime(t, z, objects), t_input, x, Options);
                toc
            end
            system.plotOrbit(t, y, length(objects),objects);
        end
        
    end
    
end
