function playui(session)

if isempty(session.Viewing)   
    sys = session.System;
    
    % initialize ui
    if isempty(session.Figure)
        session.Figure = figure('Name','Solar System Simulator, by Daniel Andrews and Marco Marquez',...
            'NumberTitle','off');
        fpos = get(session.Figure,'Position');
        set(session.Figure, ...
            'Units', 'normalized', ...
            'Position',[.05,.15,.9,.8]);
    end
    
    % Panel of Solar System
    sysPanel = uipanel('Parent',session.Figure,...
        'Units','normalized',...
        'Position',[0,0,.5,1],...
        'BackgroundColor','black'); 
    sysAxes = axes('Parent',sysPanel,'Position',[.05,.05,.95,.95]);
    axes(sysAxes)
    display(sys)
    defaultview = get(sysAxes,'CameraPosition');
    axis off;
    set(gcf, 'Resize', 'off');
    set(gcf, 'MenuBar', 'none')
    set(gcf, 'ToolBar', 'none');
    set(sysAxes, 'Color', 'black'); % DO NOT REMOVE!!!!
    
    %Panel for Right side
    buttonPanel = uipanel('Parent',session.Figure,...
        'Position',[.5,0,.5,1]);
    
    %Panel for menu of Basic, Adv, Create Planet
    topPanel = uipanel('Parent', buttonPanel,...
        'Units', 'normalized', ...
        'BorderWidth', 0, ...
        'Position', [0 .95 1 .05] );
    
    ButtonGroup = uibuttongroup('visible', 'on', 'parent', topPanel,...
        'BorderWidth', 0, 'SelectionChangeFcn', @change_callback );
    
    BasicButton = uicontrol ( 'Parent', ButtonGroup, ...
        'Units', 'normalized', ...
        'Position', [.1 0 .2 1], ...
        'Style', 'text', ...
        'String', 'Basic', ...
        'FontSize',10,...
        'Tag', 'Basic',...
        'Style', 'togglebutton');
        
    AdvButton = uicontrol ( 'Parent', ButtonGroup, ...
        'Units', 'normalized', ...
        'Position', [.4 0 .2 1], ...
        'Style', 'text', ...
        'Tag', 'Advanced', ...
        'String', 'Advanced', ...
        'FontSize',10,...
        'Style', 'togglebutton');
    
    CrtPlanButton = uicontrol ( 'Parent', ButtonGroup, ...
        'Units', 'normalized', ...
        'Position', [.7 0 .2 1], ...
        'Style', 'text', ...
        'Tag', 'Create Planet', ...
        'String', 'Create System', ...
        'FontSize',10,...
        'Style', 'togglebutton');  
    
    %Panel for Basic / Adv 
    basicPanel = uipanel('Parent', buttonPanel,...
        'Units', 'normalized', ...
        'BorderWidth', 0, ...
        'Position', [0 0 1 .95] );
    %Panel for CrtPlanet
    createPanel = uipanel('Parent',buttonPanel,...
        'Units','normalized', ...
        'BorderWidth', 0, ...
        'Position', [0 0 1 .95], ...
        'visible','off');
    
    instructButton2 = uicontrol('Parent',basicPanel,...
        'Units','normalized',...
        'Position',[.5 .5 .2 .05],...
        'Style','text',...
        'String','Instructions',...
        'FontSize',10,...
        'Style','pushbutton',...
        'Callback',@instructions_callback2);
    

    %%%%%%%%%%%%%%%%%%%%%%%%%%%% BEGIN CREATE %%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%% begin Instructions %%%%%%%%%%%%%%%%%%%%%
    instructButton = uicontrol('Parent',createPanel,...
        'Units','normalized',...
        'Position',[.3 .85 .4 .05],...
        'Style','text',...
        'String','Instructions to Create System',...
        'FontSize',10,...
        'Style','pushbutton',...
        'Callback',@instructions_callback);
        
    %%%%%%%%%%%%%%%%%%%% end Instructions %%%%%%%%%%%%%%%%%%%%%%%    
    
    activePlanetsPanel = uipanel('Parent', createPanel, ...
        'Units', 'normalized', ...
        'Position', [0.05 .4 .3 .3], ...
        'FontSize', 11,...
        'Title', 'Active Planets');
    
    activePlanetsControl = uicontrol('Parent', activePlanetsPanel, ...
        'Units', 'normalized', ...
        'Position', [0, 0, 1, 1], ...
        'Style', 'text', ...
        'String', 'Sun',...
        'FontSize',10);
    
    paramPanel = uipanel('Parent',createPanel,...
        'Units','normalized',...
        'Position',[0.45 .4 .5 .3]);
    
    createNewPlanetButton = uicontrol('Parent',paramPanel,...
        'Units','normalized',...
        'Position',[.175,.9,.65,.21],...
        'Style','text',...
        'String','Create New Planet',...
        'FontSize',10,...
        'Style','pushbutton',...
        'Callback',@createNewPlanet_callback);
    
    %%%%%%%%%%%%%%%% begin Angle Inclination %%%%%%%%%%%%%%%%
    
    anglePanel = uipanel('Parent', paramPanel, ...
        'Units', 'normalized', ...
        'BorderWidth', 0, ...
        'Position', [0, .4, 1, .5]);

    angleText = uicontrol('Parent',anglePanel,...
        'Units','normalized',...
        'Position',[0,0,.75,.6],...
        'Style','text',...
        'FontSize',10,...
        'String','Enter Angle of Inclination');
    
    angleEdit = uicontrol('Parent',anglePanel,...
        'Units','normalized',...
        'Position',[.75, 0.25, .2, .35],...
        'Style','edit',...
        'BackgroundColor','white');
    %%%%%%%%%%%%%%%%%% begin Mass  %%%%%%%%%%%%%%%%%%
    massPanel = uipanel('Parent', paramPanel, ...
        'Units', 'normalized', ...
        'BorderWidth', 0, ...
        'Position', [0, 0, 1, .5]);
    
    massText = uicontrol('Parent',massPanel,...
        'Units','normalized',...
        'Position',[0,0,.75,.6],...
        'Style','text',...
        'FontSize',10,...
        'String','Enter Mass in Kg');
    
    massEdit = uicontrol('Parent',massPanel,...
        'Units','normalized',...
        'Position',[.75, 0.25, .2, .35],...
        'Style','edit',...
        'BackgroundColor','white');
    %%%%%%%%%%% end Mass %%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%% begin Time %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    time1Panel = uipanel('Parent', createPanel, ...
        'Units', 'normalized', ...
        'BorderWidth', 0, ...
        'Position', [.2, 0.2, .5, .2]);
    
    timeframe1Text = uicontrol('Parent',time1Panel,...
        'Units','normalized',...
        'Position',[0,.25,.8,.3],...
        'Style','text',...
        'FontSize',10,...
        'String','Enter Number of Years for Simulation');
    
    timeframe1Edit = uicontrol('Parent',time1Panel,...
        'Units','normalized',...
        'Position',[.8, 0.275, .2, .25],...
        'Style','edit',...
        'BackgroundColor','white');
    %%%%%%%%%%%%%%%%% end Time %%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    beginsimulationButton = uicontrol('Parent',createPanel,...
        'Units','normalized',...
        'Position',[.55,.13,.25,.05],...
        'Style','text',...
        'String','Begin Simulation',...
        'Style','pushbutton',...
        'FontSize',10,...
        'Callback',@beginsimulation_callback);
    
    reset1Button = uicontrol('Parent',createPanel,...
        'Units','normalized',...
        'Position',[.25, .13, .2, .05],...
        'Style','text',...
        'String','Reset',...
        'FontSize',10,...
        'Style','pushbutton',...
        'Callback',@reset1_axis);
    
    reset2Button = uicontrol('Parent', sysPanel,...
        'Units', 'normalized', ...
        'Position', [.9, .95, .1, .05], ...
        'String', 'Reset System',...
        'Style', 'pushbutton',...
        'Visible', 'off', ...
        'Callback', @reset2_callback);
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% END CREATE %%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% BASIC %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    planetText = uicontrol('Parent',basicPanel,...
        'Units','normalized',...
        'Position',[.1 .83 .18 .1],...
        'Style','text',...
        'String','Select Planets: ');
    
    planetMenu = uicontrol('Parent',basicPanel,...
        'Units','normalized',...
        'Position',[.1,.8, .2, .1],...
        'String',{'Mercury','Venus','Earth','Mars','Jupiter','Saturn','Uranus','Neptune', 'Inner Planets', 'Outer Planets'},...
        'Style','popupmenu',...
        'BackgroundColor','white', ...
        'Callback', @getMoons);
   
    moonsBox = uicontrol('Parent',basicPanel,...
        'Units','normalized',...
        'Position',[.35,.85,.05,.05],...
        'Style','checkbox');
    
    moonsText = uicontrol('Parent',basicPanel,...
        'Units','normalized',...
        'Position',[.4,.8,.1,.1],...
        'Style','text',...
        'String','Include Moons?');
    
    %panel to display moons
    moonsPanel = uipanel('Parent', basicPanel, ...
        'Units', 'normalized', ...
        'BorderWidth', 1, ...
        'Position', [.65, .83, .15, .14], ...
        'Title', 'Moons');
    
    moonsControl = uicontrol('Parent', moonsPanel, ...
        'Units', 'normalized', ...
        'Style', 'text', ...
        'String', 'No Moons', ...
        'Position', [0, 0, 1, 1]);

    % need to include planet's image and info
    planetPanel = uipanel('Parent', basicPanel, ...
        'Units', 'normalized', ...
        'Position', [.2 .6 .5, .2], ...
        'BorderWidth', 0);
    
    %panel for the image
    imagePanel = uipanel('Parent', planetPanel, ...
        'Units', 'normalized', ...
        'Position', [0, 0, .5, .92], ...
        'BackgroundColor', 'white', ...
        'BorderWidth', 0);
    
    imAxes = axes('Parent',imagePanel,'Units', 'normalized', ...
        'Position', [0, 0, 1, 1],...
        'Color','k');
        axes(imAxes)    
        colormap gray
        Me = imread('Mercury_image.jpg');
        V = imread('Venus_image.jpg');
        E = imread('Earth_image.jpg');
        M = imread('Mars_image.jpg');
        J = imread('Jupiter_image.jpg');
        S = imread('Saturn_image.jpg');
        N = imread('Neptune_image.jpg');
        U = imread('Uranus_image.jpg');
        IP = imread('inner_planets.jpg');
        OP = imread('outer_planets.jpg');
        %initializes an image in the panel
        imagesc(Me);
        axis off
    
    %panel for the info
    infoPanel = uipanel('Parent', planetPanel, ...
        'Units', 'normalized', ...
        'Title', 'Stats', ...
        'Position', [.52, 0, .48, 1]);
    
    infoControl = uicontrol('Parent', infoPanel, ...
        'Units', 'normalized', ...
        'Position', [0, 0, 1, 1], ...
        'Style', 'text', ...
        'String', sprintf('Mass: 3.30e23 kg\nPos: 5.79e07 km\n Vel: 1.51e09 km/yr\nIncline: 6.34'));

    addButton = uicontrol('Parent',basicPanel,...
        'Units','normalized',...
        'Position',[.23,.5,.2,.05],...
        'Style','text',...
        'String','Add',...
        'Style','pushbutton',...
        'Callback',@(h,e) submit_callback(h, e));

    %%%% TIME
    timePanel = uipanel('Parent', basicPanel, ...
        'Units', 'normalized', ...
        'BorderWidth', 0, ...
        'Position', [.35, .3, .5, .05]);
    
    timeframeText = uicontrol('Parent',timePanel,...
        'Units','normalized',...
        'Position',[0,0,.8,1],...
        'Style','text',...
        'String','Time for simulation (Earth years):');
    
    timeframeEdit = uicontrol('Parent',timePanel,...
        'Units','normalized',...
        'Position',[.81, .33, .13, .8],...
        'Style','edit',...
        'BackgroundColor','white');
        
    
    actPlanetsPanel = uipanel('Parent', basicPanel, ...
        'Units', 'normalized', ...
        'Position', [.1 .22 .18, .23], ...
        'Title', 'Active Planets');
    
    %panel for the image
    actPlanetsControl = uicontrol('Parent', actPlanetsPanel, ...
        'Units', 'normalized', ...
        'Position', [0, 0, 1, 1], ...
        'Style', 'text', ...
        'String', 'Sun');
        
    
    
    
    
    
    %%% TOOLS
    
    toolsPanel = uipanel('Parent', buttonPanel, ...
        'Units', 'normalized', ...
        'BorderWidth', 1, ....
        'Position', [0, .012, 1, .08], ...
        'Title', 'Tools');
    
    GrayScaleBox = uicontrol('Parent',toolsPanel,...
        'Units','normalized',...
        'Position',[0.05,0,0.03,1],...
        'Style','checkbox', ...
        'Callback', @grayscale);    
     
    GrayScaleOpt = uicontrol('Parent', toolsPanel, ...
        'Units', 'normalized', ...
        'Position', [.09, 0, .102, .9], ...
        'Style', 'text', ...
        'String', 'White View');
    
    AxesBox = uicontrol('Parent',toolsPanel,...
        'Units','normalized',...
        'Position',[.2875,0,.03,1],...
        'Style','checkbox', ...
        'Callback', @noaxes);    
    
    AxesOpt = uicontrol('Parent', toolsPanel, ...
        'Units', 'normalized', ...
        'Position', [.3275, 0.4, .102, .4], ...
        'Style', 'text', ...
        'String', 'Axes');
    
    Option3Box = uicontrol('Parent',toolsPanel,...
        'Units','normalized',...
        'Position',[.525, 0, .03, 1],...
        'Style','checkbox', ...
        'Value', 0, ...
        'Callback', @opts_callback); 
    
    Option3 = uicontrol('Parent', toolsPanel, ...
        'Units', 'normalized', ...
        'Position', [.565, 0.4, .102, .4], ...
        'Style', 'text', ...
        'String', 'Tool Bar');
    
    Option4Box = uicontrol('Parent',toolsPanel,...
        'Units','normalized',...
        'Position',[.7625, 0, .03, 1],...
        'Style','checkbox'); 
    
    Option4 = uicontrol('Parent', toolsPanel, ...
        'Units', 'normalized', ...
        'Position', [.8025, 0, .12, .9], ...
        'Style', 'text', ...
        'String', 'Save ODE Output?');    

    simulationButton = uicontrol('Parent',basicPanel,...
        'Units','normalized',...
        'Position',[.55,.13,.25,.05],...
        'Style','text',...
        'String','Begin Simulation',...
        'Style','pushbutton',...
        'Callback',@(h,e,s) simulation_callback(h,e,session));
   
    resetButton = uicontrol('Parent',basicPanel,...
        'Units','normalized',...
        'Position',[.25, .13, .2, .05],...
        'Style','text',...
        'String','Reset',...
        'Style','pushbutton',...
        'Callback',@(h,e) reset_basic(h,e));
    
    breakButton = uicontrol('Parent', sysPanel,...
        'Units', 'normalized', ...
        'Position', [.9, .95, .1, .05], ...
        'String', 'Reset System',...
        'Style', 'pushbutton',...
        'Visible', 'off', ...
        'Callback', @(h,e) break_callback(h,e));
    
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% END OF BASIC %%%%%%%%%%%%%%%%%%%%%%%%% 
    %%%%%%%%%%%%%%%%%%%%%%% ADVANCED %%%%%%%%%%%%%%%%%%%%%%%%%5

    odePanel = uipanel('Parent', basicPanel, ...
        'Units', 'normalized', ...
        'Position', [.2 .63, .45, .15], ...
        'Visible', 'off', ...
        'Title', 'ODE Settings');
    
    odeDropD = uicontrol('Parent', odePanel, ...
        'Units', 'normalized', ...
        'Position', [0.03, .5, .277, .2], ...
        'Style', 'text', ...
        'String', {'ode45', 'ode15s', 'ode23', 'ode23s','s3odr4','s5odr4a', 's7odr6','s9odr6a','s15odr8'}, ...
        'Style', 'popupmenu', ...
        'BackgroundColor', 'white');
    
    odeSteptext=uicontrol('Parent', odePanel, ...
        'Units', 'normalized', ...
        'Position', [.3, .77, .4, .18], ...
        'Style', 'text', ...
        'String', 'Time step:');
    
    odeStepEdit=uicontrol('Parent', odePanel, ...
        'Units', 'normalized', ...
        'Position', [.7, .75, .15, .2], ...
        'Style', 'edit', ...
        'BackgroundColor', 'white');
   
    odeErrortext=uicontrol('Parent', odePanel, ...
        'Units', 'normalized', ...
        'Position', [.3, .35, .4, .15], ...
        'Style', 'text', ...
        'String', 'Tolerance:');
    
    odeErrorEdit=uicontrol('Parent', odePanel, ...
        'Units', 'normalized', ...
        'Position', [.7, .3, .25, .2], ...
        'Style', 'edit', ...
        'BackgroundColor', 'white');
    
    %%%% END OF ADVANCED
     axes(sysAxes)
     display(sys)
else
    axes(sysAxes)
    session.view()
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% CALLBACKS %%%%%%%%%%%%%%%%%%%%%%%%%%%%
    function change_callback(hObject, eventdata)
        switch get(eventdata.NewValue, 'Tag')
            case 'Basic'
                set(basicPanel, 'visible', 'on')
                set(planetPanel, 'visible', 'on')
                set(odePanel, 'visible', 'off')
                set(createPanel,'visible','off')
                cla(sysAxes)
                resetSystem(sys)
                axes(sysAxes)
                set(sysAxes,'CameraPosition',defaultview)
                set(planetMenu, 'Value', 1);
                set(moonsControl, 'String', 'No Moons');
                set(infoControl, 'String', sprintf('Mass: 3.30e23 kg\nPos: 5.79e07 km\nVel: 1.51e09 km/yr\nIncline: 6.34'))
                display(sys)
                axes(imAxes)
                imagesc(Me)
                axis off
                
            case 'Advanced'
                set(basicPanel, 'visible', 'on');
                set(planetPanel, 'visible', 'off');
                set(odePanel, 'visible', 'on');
                set(createPanel, 'visible','off')
                %reset to mercury
                set(planetMenu, 'Value', 1);
                set(moonsControl, 'String', 'No Moons');
                set(infoControl, 'String', sprintf('Mass: 3.30e23 kg\nPos: 5.79e07 km\nVel: 1.51e09 km/yr\nIncline: 6.34'))
                cla(sysAxes)
                resetSystem(sys)
                axes(sysAxes)
                set(sysAxes,'CameraPosition',defaultview)
                display(sys)
                
            case 'Create Planet'
                set(basicPanel, 'visible', 'off')
                set(createPanel,'visible','on')
                cla(sysAxes)
                resetSystem(sys)
                axes(sysAxes)
                set(sysAxes,'CameraPosition',defaultview)
                display(sys)
        end
    end

    function getMoons(hObject, eventdata)
        plnts = get(planetMenu,'String');
        axes(imAxes)
        set(moonsBox, 'Enable', 'on');
        switch plnts{get(planetMenu,'Value')}
            case 'Mercury'
                set(moonsControl, 'String', 'No Moons');
                imagesc(Me);
                set(infoControl, 'String', sprintf('Mass: 3.30e23 kg\nPos: 5.79e07 km\nVel: 1.51e09 km/yr\nIncline: 6.34'))
            case 'Venus'
                set(moonsControl, 'String', 'No Moons');
                imagesc(V);
                set(infoControl, 'String', sprintf('Mass: 4.87e23 kg\nPos: 1.08e08 km\nVel: 1.10e09 km/yr\nIncline: 2.19'))
            case 'Earth'
                set(moonsControl, 'String', 'Moon');
                imagesc(E);    
                set(infoControl, 'String', sprintf('Mass: 5.97e24 kg\nPos: 1.47e08 km\nVel: 9.4e08 km/yr\nIncline: 6.67'))
            case 'Mars'
                set(moonsControl, 'String', sprintf('Phobos\nDeimos'));
                imagesc(M);
                set(infoControl, 'String', sprintf('Mass: 6.42e23 kg\nPos: 2.40e08 km\nVel: 7.60e08 km/yr\nIncline: 1.67'));
            case 'Jupiter'
                set(moonsControl, 'String', sprintf('Io\nEuropa\nGanymede\nCallisto'));
                imagesc(J);
                set(infoControl, 'String', sprintf('Mass: 1.90e27 kg\nPos: 7.78e08 km\nVel: 4.52e08 km/yr\nIncline: 0.32'));
            case 'Saturn'
                set(moonsControl, 'String', sprintf('Titan\nRhea\nIapetus\nDione'));
                imagesc(S);
                set(infoControl, 'String', sprintf('Mass: 5.69e26 kg\nPos: 1.49e09 km\nVel: 3.35e08 km/yr\nIncline: 0.93'));
            case 'Uranus'
                set(moonsControl, 'String', sprintf('Titania\nOberon\nAriel\nUmbriel'));
                imagesc(U);
                set(infoControl, 'String', sprintf('Mass: 8.68e25 kg\nPos: 2.87e09 km\nVel: 2.35e08 km/yr\nIncline: 1.02'));
            case 'Neptune'
                set(moonsControl, 'String', 'Triton');
                imagesc(N);
                set(infoControl, 'String', sprintf('Mass: 1.02e26 kg\nPos: 4.50e09 km\nVel: 1.88e08 km/yr\nIncline: 0.72'));
            case 'Inner Planets'
                set(moonsControl, 'String', 'Moons Not Included');
                set(infoControl, 'String', sprintf('Mercury\nVenus\nEarth\nMars'));
                imagesc(IP);
                set(moonsBox, 'Enable', 'off');
            case 'Outer Planets'
                imagesc(OP);
                set(moonsControl, 'String', 'Moons Not Included');
                set(infoControl, 'String', sprintf('Jupiter\nSaturn\nUranus\nNeptune'));
                set(moonsBox, 'Enable', 'off');
        end
        axis off
    end

    function grayscale(hObject, eventdata)
        axes(sysAxes)
        if get(hObject, 'Value')== 1
            set(sysPanel, 'BackgroundColor', 'white')
            set(sysAxes, 'Color', 'white');
        else
            set(sysPanel, 'BackgroundColor', 'black')
            set(sysAxes, 'Color', 'black');
        end
    end

    function noaxes(hObject, eventdata)
        axes(sysAxes)
        if get(hObject, 'Value') == 0
        set(sysAxes,'Visible', 'off');
        else
            if get(sysPanel, 'BackgroundColor') == 1
                set(sysAxes, 'Xcolor', [0 0 0]);
                set(sysAxes, 'Ycolor', [0 0 0]);
                set(sysAxes, 'Zcolor', [0 0 0]);
            elseif get(sysPanel, 'BackgroundColor') == 0
                set(sysAxes, 'Xcolor', [1 1 1]);
                set(sysAxes, 'Ycolor', [1 1 1]);
                set(sysAxes, 'Zcolor', [1 1 1]);
            end
            set(sysAxes, 'Visible', 'on');
        end
    end

    function opts_callback(hObject, eventdata)
        if get(hObject, 'Value')== 1
            set(gcf, 'MenuBar', 'figure')
            set(gcf, 'ToolBar', 'figure')
        else set(gcf, 'MenuBar', 'none')
            set(gcf, 'ToolBar', 'none');
        end
    end

    function opt4_callback(hObject, eventdata) %save output of ODE
        
    end

    function opt5_callback(hObject, eventdata)
    end
            
            

    function submit_callback(hObject,eventdata)
        plnts = get(planetMenu,'String');
        planet = plnts{get(planetMenu,'Value')};
        if strcmpi(planet, 'Inner Planets')
            construct_planet('Mercury', sys);
            construct_planet('Venus', sys);
            construct_planet('Earth', sys);
            construct_planet('Mars', sys);
        elseif strcmpi(planet, 'Outer Planets')
            construct_planet('Jupiter', sys);
            construct_planet('Saturn', sys);
            construct_planet('Uranus', sys);
            construct_planet('Neptune', sys);
        else
            construct_planet(planet, sys);
        end
        
        sys.ActivePlanets{end}.IncludeMoons = get(moonsBox,'Value');
        update_planets(sys);
        axes(sysAxes)
        display(sys)
    end

    function construct_planet(planet_string, system)
        pl=str2func(planet_string);
        pl(system);
    end

    function update_planets(system)
        p=[];
        for i=1:length(sys.ActivePlanets)
            p=strvcat(p, sys.ActivePlanets{i}.Name);
        end
        set(actPlanetsControl, 'String', p);
    end


function simulation_callback(hObject,eventdata, session)
        years = str2num(get(timeframeEdit,'String'));
        if isempty(years)
            years=1; %default years
        end
        ode_options=get(odeDropD, 'String'); %all possible ode's
        ode_selected=ode_options(get(odeDropD, 'Value')); %ode selected
        extra={years ode_selected};
        
        if ~isempty(get(odeStepEdit, 'String'))
            ode_step=str2num(get(odeStepEdit, 'String')); %scalar
            extra{end+1}=ode_step;
        else
            ode_step=0.1;
            extra{end+1}=ode_step;
        end
        
        if ~isempty(get(odeErrorEdit, 'String')) % the nested if respects required order for solveODE method
            ode_error=eval(get(odeErrorEdit, 'String')); % vector (1x2)
            extra{end+1} = ode_error;
        else
            extra{end+1}=[1e3, 1e-6];
        end
           
        set(buttonPanel,'Visible','off')
        set(sysPanel,'Position',[0,0,1,1])
        set(sysAxes,'Position',[.1,.1,.8,.8])
        set(breakButton, 'Visible', 'on')
        sys=session.System;
        [t, y] = solveODE(sys, session,extra);
        if get(Option4Box, 'Value') == 1
            save ode_output t y %save to current directory
            [t y]  %output to command prompt
        end
    end

    function reset_basic(hobject,eventdata)
        set(timeframeEdit, 'String', '');
        set(moonsBox, 'Value', 0);
        set(odeStepEdit, 'String', '');
        set(odeErrorEdit, 'String', '');
        set(actPlanetsControl, 'String', 'Sun');
        %clear image
        cla(sysAxes)
        resetSystem(sys)
        axes(sysAxes)
        display(sys)
    end

    function break_callback(hobject, eventdata)
        session.Viewing=[];
        set(buttonPanel,'Visible','on')
        set(sysPanel,'Position',[0,0,.5,1])
        set(sysAxes,'Position',[.05,.05,.95,.95]);
        set(actPlanetsControl, 'String', 'Sun');
        set(breakButton,'visible','off')
        cla(sysPanel)
        resetSystem(sys)
        axes(sysAxes)
        display(sys)

    end

%%%%%%% functions and callbacks for CREATE PLANET %%%%%%%%%%
    function instructions_callback(h,e)
        instructFig = figure('Name','Instructions','DockControls','off',...
            'NumberTitle','off', 'Resize','off','toolbar','none','menubar','none');
        fpos = get(instructFig,'Position');
        set(instructFig, ...
            'Units', 'normalized', ...
            'Position',[.55,.4,.4,.5]);
        pos = [0 0 1 1];
        instructText = uicontrol('Parent',instructFig,'Style','text','FontSize',10,'Units','normalized','Position',pos);
        string = {'This mode lets you experiment with different initial positions, velocities, and masses for bodies revolving around the Sun. To begin, click the button ''Create New Planet''. A planet will appear in the panel to the left. Click and drag the planet to any position, and double click to fix it in it''s initial position. A vector will appear. Click and drag the free end to adjust the length and angle of the vector relative to the Sun. A longer length corresponds to a faster velocity. Fill in parameters in the boxes below and then double click the free end point of the vector to fix the initial velocity and create the planet with the specified parameters. The mass parameter can be any positive number, but it should be in the form 10^x. For example, the Earth''s mass is roughly 10^24, and the Sun''s is roughly 10^30. For the angle parameter, specify a degree between -90 and 90. For example, Earth''s angle of inclination is roughly 6 degrees. If no values are entered, the default mass is 10^24 and the default angle is 0. Remember, the planet has not been created until the free end point of the velocity vector has been double-clicked. See which planets you have successfully added by looking at the ''Active Planets'' box. Last, enter a time in Earth years for the simulation to run. The default time is 1, representing 1 Earth year. Once all the desired planets have been added to the system, press ''Begin Simulation'' to run the simulation. Reset the system by pressing the ''Reset'' button, which returns the system to it''s initial state.'};
        set(instructText,'String',string)
    end

    function instructions_callback2(h,e)
        instructFig = figure('Name','Instructions','DockControls','off',...
            'NumberTitle','off', 'Resize','off','toolbar','none','menubar','none');
        fpos = get(instructFig,'Position');
        set(instructFig, ...
            'Units', 'normalized', ...
            'Position',[.55,.4,.4,.5]);
        pos = [0 0 1 1];
        instructText = uicontrol('Parent',instructFig,'Style','text','FontSize',10,'Units','normalized','Position',pos);
        string = sprintf('In basic and advanced mode, you can simulate the solar system by solving Ordinary Differential Equations (ODE).\n In basic mode, you can add planets, their moons and input time desired for simulation.\n In advanced mode, you are given the same options as in basic mode however there are three extra options: ODE solver, ODE Time Step and ODE Tolerance. For the ODE Step, it is a scalar that is recommended to be less than 0.05 due to stability issues, where MATLAB may take over and decrease the time step automatically. The Tolerance field takes a 1 by 2 array, which specify the Absolute tolerance and Relative tolerance, respectively.\n In the tool bars in the bottom, you can change the background from black to white, show or hide the axes, show or hide the top toolbar or save the output of the ODE (time and position) in your hard drive ~ode_output.mat. This file can easily be plotted by running the function plotoutput.m in the same folder as ode_output.mat and you will get a plot without having to solve any ODE.\nIt is important to note that any fields that are empty will automatically take the default values.');
        set(instructText,'String',string)
    end


    function createNewPlanet_callback(h,e)
        % the following code handles the placement of the planet and its
        % velocity
        
        set(angleEdit,'String','')
        set(massEdit,'String','')
        colors = {'b' 'g' 'r' 'c' 'm'};
        symbs= {'A' 'B' 'C' 'D' 'E' 'F' 'G' 'H' 'I' 'J'};
        markers = {'.' 'o' 'x' '+' '*' 's' 'd' 'p' 'h'};
        symb = symbs{randi(10)};
        bodycolor = colors{randi(5)};
        bodymarker = markers{randi(9)};
        initposition = [];
        init_veloc = [];
        body = impoint(sysAxes,1.4E8,0);
        setColor(body,bodycolor);
        fcn = makeConstrainToRectFcn('impoint',.9*get(sysAxes,'XLim'),.9*get(sysAxes,'YLim'));
        setPositionConstraintFcn(body,fcn);
        %wait requires a double click to proceed
        initposition = wait(body);
        if isempty(initposition)
            return
        end
        iveloc = [-initposition(2),initposition(1)]; %perpendicular vector
        vec = (iveloc + initposition);
        v = imdistline(sysAxes,[initposition(1) vec(1)],[initposition(2) vec(2)]);
        api = iptgetapi(v);
        api.setLabelTextFormatter('')
        xlim = get(sysAxes,'XLim');
        ylim = get(sysAxes,'YLim');
        fun = makeConstrainToRectFcn('imline',.9*xlim,.9*ylim);
        api.setDragConstraintFcn(fun);
        api.setPositionConstraintFcn(fun)
        f = @(pos)FUN(pos);
        api.setPositionConstraintFcn(f);
        setColor(v,bodycolor)
        % wait requires a double click for the rest of the code to execute
        init_veloc = wait(v);
        if isempty(init_veloc)
            return
        end
        % lock init_veloc in place
        g = @(pos)FUN2(pos);
        api.setPositionConstraintFcn(g);
        % The following code creates a Planet X
        X = Planet(sys);
        X.OrbitColor = [bodycolor bodymarker];
        X.MarkerSize = 10;
        X.Symbol = [bodycolor symb];
        X.Moons = {};
        
        P = getPosition(v);
        U = P(1,:);
        V = P(2,:);
        xvec = V-U;
        xvec = [xvec 0 0]';
        direction = sign(xvec(2));
        if isempty(get(angleEdit,'String'))
            X.Inclination = 0;
        else
            X.Inclination = direction*(pi/180)*(str2num(get(angleEdit,'String')));
        end
        if isempty(get(massEdit,'String'))
            X.Mass = 5.9736*10^24; % Earth's mass in kg
        else
            X.Mass = str2num(get(massEdit,'String'));
        end
       
        a = X.Inclination;
        Xrotate = makehgtform('xrotate',a);
        newX = Xrotate*xvec;
        X.InitialVelocity = 7.1725*[newX(1),newX(2),newX(3)];
        X.InitialPosition = [init_veloc(1,1) init_veloc(1,2) 0];
        X.DistanceFromSun = norm(init_veloc(1,:),2);
        X.IncludeMoons = 0;
        n = length(sys.ActivePlanets);
        X.Name = ['Planet ' num2str(n)];
        addPlanet(sys,X)
        update_planets2(sys);
        axes(sysAxes)
        set(sysAxes,'CameraPosition',defaultview)
        display(sys)
        
        function candidate_pos = FUN(pos)
            newpos = fun(pos);
            endpos = getPosition(body);
            newx = [endpos(1),newpos(2,1)]';
            newy = [endpos(2),newpos(2,2)]';
            candidate_pos = [newx, newy];
        end
        
        function candidate_pos = FUN2(pos)
            candidate_pos = init_veloc;
        end
             
    end

    function beginsimulation_callback(h,e)
        if length(sys.ActivePlanets)==1
            return
        end
        if isempty(get(timeframe1Edit,'String'))
            years = 1;
        else
            years = str2num(get(timeframe1Edit,'String'));
        end
        set(buttonPanel,'Visible','off')
        set(sysPanel,'Position',[0,0,1,1])
        set(sysAxes,'Position',[.1,.1,.8,.8])
        set(reset2Button,'Visible','on')
        [t,y]=solveODE(sys, session,{years {'ode45'} .01 [1E-6 1E-3]});
        if get(Option4Box, 'Value') == 1
            save ode_output t y %save to current directory
            [t y]  %output to command prompt
        end
    end

    function reset1_axis(h,e)
        set(angleEdit,'String','')
        set(massEdit,'String','')
        set(timeframe1Edit,'String','')
        cla(sysAxes)
        resetSystem(sys)
        update_planets2(sys)
        axes(sysAxes)
        set(sysAxes,'CameraPosition',defaultview)
%         view(0,90)
        display(sys)
    end

    function reset2_callback(h,e)
        set(angleEdit,'String','')
        set(massEdit,'String','')
        set(timeframe1Edit,'String','')
        set(buttonPanel,'Visible','on')
        set(sysPanel,'Position',[0,0,.5,1])
        set(sysAxes,'Position',[.05,.05,1,1]);
        set(reset2Button,'visible','off')
        cla(sysAxes)
        resetSystem(sys)
        update_planets2(sys)
        axes(sysAxes)
%         view(0,90)
        set(sysAxes,'CameraPosition',defaultview)
        display(sys)
    end
    function update_planets2(system)
        p=[];
        for i=1:length(sys.ActivePlanets)
            p=strvcat(p, sys.ActivePlanets{i}.Name);
        end
        set(activePlanetsControl, 'String', p);
    end
end

  
  
